@@ -376,6 +376,8 @@ int main(int argc, char **argv)
 	unsigned int i, j;
 	struct cli_environment env;
 
+    cl_initialize_crypto();
+
     opts = optparse(NULL, argc, argv, 1, OPT_CLAMCONF, 0, NULL);
     if(!opts) {
 	printf("ERROR: Can't parse command line options\n");
@@ -486,5 +488,6 @@ int main(int argc, char **argv)
     cli_detect_environment(&env);
     print_platform(&env);
     print_build(&env);
+    cl_cleanup_crypto();
     return 0;
 }
