@@ -302,9 +302,7 @@ main (int argc, char **argv)
     if (check_flevel ())
         exit (FCE_INIT);
 
-#if defined(_WIN32)
     cl_initialize_crypto();
-#endif
 
     if ((retcl = cl_init (CL_INIT_DEFAULT)))
     {
@@ -743,6 +741,8 @@ main (int argc, char **argv)
 
     optfree (opts);
 
+    cl_cleanup_crypto();
+
     return (ret);
 }
 
@@ -759,6 +759,12 @@ void submit_host_info(struct optstruct *opts)
     if (!(engine))
         return;
 
+    if (optget (opts, "Debug")->enabled || optget (opts, "debug")->enabled)
+        cl_debug ();
+
+    if (optget (opts, "verbose")->enabled)
+        mprintf_verbose = 1;
+
     cl_engine_stats_enable(engine);
 
     intel = engine->stats_data;
