@@ -23,6 +23,11 @@
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
 #endif
+
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#include "libclamav/crypto.h"
+
 #include "target.h"
 #include "cltypes.h"
 
