@@ -34,6 +34,10 @@
 #include <ctype.h>
 #include <assert.h>
 
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#include "libclamav/crypto.h"
+
 #include "cltypes.h"
 #include "jsparse/lexglobal.h"
 #include "hashtab.h"
