@@ -52,6 +52,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#include "libclamav/crypto.h"
+
 #include "cltypes.h"
 #include "rebuildpe.h"
 #include "execs.h"
