@@ -41,6 +41,11 @@
 #include <ctype.h>
 #include <limits.h>
 #include <stdlib.h>
+
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#include "libclamav/crypto.h"
+
 #include "others.h"
 #include "regex.h"
 
