@@ -28,6 +28,10 @@
 #include <string.h>
 #include <assert.h>
 
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#include "libclamav/crypto.h"
+
 #include "others.h"
 #include "jsparse/textbuf.h"
 #include "regex_suffix.h"
